==> style-o-matic-1.1.5.tgz: package/es/components/Pill/Pill.js <==
var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, setCorePropDefaults, setPropTypesA11y, getValidProps, ROLE } from "../../lib";
import "./Pill.css";

var Pill = (_temp2 = _class = function (_CoreComponent) {
  _inherits(Pill, _CoreComponent);

  function Pill() {
    var _temp, _this, _ret;

    _classCallCheck(this, Pill);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this), _this.handleOnRemove = function (e) {
      var _this$props = _this.props,
          pillData = _this$props.pillData,
          onRemove = _this$props.onRemove;

      if (!_this.props.disabled && onRemove) {
        e.preventDefault();
        onRemove(pillData);
      }
    }, _this.handleOnAction = function (e) {
      var _this$props2 = _this.props,
          pillData = _this$props2.pillData,
          onAction = _this$props2.onAction;

      if (!_this.props.disabled && onAction) {
        e.preventDefault();
        onAction(pillData);
      }
    }, _this.renderAction = function () {
      var _this$props3 = _this.props,
          actionIcon = _this$props3.actionIcon,
          onAction = _this$props3.onAction;

      if (onAction) {
        return React.createElement(
          "div",
          {
            className: "ui-pill-action",
            role: "presentation",
            onClick: _this.handleOnAction
          },
          React.createElement("i", { className: actionIcon, "aria-hidden": "true" })
        );
      }
      return null;
    }, _this.renderRemove = function () {
      var onRemove = _this.props.onRemove;

      if (onRemove) {
        return React.createElement(
          "div",
          {
            className: "ui-pill-action",
            role: "presentation",
            onClick: _this.handleOnRemove
          },
          React.createElement("i", { className: "ui-icon ui-icon-close", "aria-hidden": "true" })
        );
      }
      return null;
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Pill.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      Component,
      props,
      this.renderAction(),
      React.createElement(
        "span",
        { className: "ui-pill-text" },
        children
      ),
      this.renderRemove()
    );
  };

  return Pill;
}(CoreComponent), _class.propTypes = setPropTypesA11y(null, {
  actionIcon: "string",
  pillData: "object",
  onRemove: "func",
  onAction: "func"
}), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.PILL,
  actionIcon: "ui-icon ui-icon-star",
  pillData: {},
  onRemove: null,
  onAction: null
}), _temp2);


export default Pill;

==> style-o-matic-1.1.37.tgz: package/es/components/Pill/Pill.js <==
var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getCorePropDefaults, getPropTypesA11y, getValidProps, ROLE } from "../../lib";
import "./Pill.css";

var Pill = (_temp2 = _class = function (_CoreComponent) {
  _inherits(Pill, _CoreComponent);

  function Pill() {
    var _temp, _this, _ret;

    _classCallCheck(this, Pill);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this), _this.handleOnRemove = function (e) {
      var _this$props = _this.props,
          pillData = _this$props.pillData,
          onRemove = _this$props.onRemove;

      if (!_this.props.disabled && onRemove) {
        e.preventDefault();
        onRemove(pillData);
      }
    }, _this.handleOnAction = function (e) {
      var _this$props2 = _this.props,
          pillData = _this$props2.pillData,
          onAction = _this$props2.onAction;

      if (!_this.props.disabled && onAction) {
        e.preventDefault();
        onAction(pillData);
      }
    }, _this.renderAction = function () {
      var _this$props3 = _this.props,
          actionIcon = _this$props3.actionIcon,
          onAction = _this$props3.onAction;

      if (onAction) {
        return React.createElement(
          "div",
          {
            className: "ui-pill-action",
            role: "presentation",
            onClick: _this.handleOnAction
          },
          React.createElement("i", { className: actionIcon, "aria-hidden": "true" })
        );
      }
      return null;
    }, _this.renderRemove = function () {
      var onRemove = _this.props.onRemove;

      if (onRemove) {
        return React.createElement(
          "div",
          {
            className: "ui-pill-action",
            role: "presentation",
            onClick: _this.handleOnRemove
          },
          React.createElement("i", { className: "ui-icon ui-icon-close", "aria-hidden": "true" })
        );
      }
      return null;
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Pill.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      Component,
      props,
      this.renderAction(),
      React.createElement(
        "span",
        { className: "ui-pill-text" },
        children
      ),
      this.renderRemove()
    );
  };

  return Pill;
}(CoreComponent), _class.propTypes = getPropTypesA11y(null, {
  actionIcon: "string",
  pillData: "object",
  onRemove: "func",
  onAction: "func"
}), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.PILL,
  actionIcon: "ui-icon ui-icon-star",
  pillData: {},
  onRemove: null,
  onAction: null
}), _temp2);


export default Pill;
